@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -55,7 +55,7 @@
 /**                # Version 5.1  : from : 01 jul 2010     **/
 /**                                 to   : 14 feb 2011     **/
 /**                # Version 6.0  : from : 01 jan 2012     **/
-/**                                 to   : 10 jul 2018     **/
+/**                                 to   : 26 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -114,7 +114,7 @@ char *                      argv[])
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
-    return     (0);
+    return     (EXIT_SUCCESS);
   }
 
   fileBlockInit (C_fileTab, C_FILENBR);           /* Set default stream pointers */
@@ -124,7 +124,7 @@ char *                      argv[])
       if (C_paraNum < 1) {                        /* If number of parameters not reached              */
         if ((fdim = atoi (argv[i])) < 1) {        /* Get the dimension                                */
           errorPrint ("main: invalid dimension '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
         }
         C_paraNum ++;
         continue;                                 /* Process the other parameters */
@@ -133,7 +133,7 @@ char *                      argv[])
         fileBlockName (C_fileTab, C_fileNum ++) = argv[i];
       else {
         errorPrint ("main: too many file names given");
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
     else {                                        /* If found an option name */
@@ -141,15 +141,15 @@ char *                      argv[])
         case 'H' :                                /* Give the usage message */
         case 'h' :
           usagePrint (stdout, C_usageList);
-          return     (0);
+          return     (EXIT_SUCCESS);
         case 'V' :
           fprintf (stderr, "amk_fft2, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS, France\n");
-          fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
-          return  (0);
+          fprintf (stderr, SCOTCH_COPYRIGHT_STRING "\n");
+          fprintf (stderr, SCOTCH_LICENSE_STRING "\n");
+          return  (EXIT_SUCCESS);
         default :
           errorPrint ("main: unprocessed option '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
       }
     }
   }
@@ -157,9 +157,11 @@ char *                      argv[])
   fileBlockOpen (C_fileTab, C_FILENBR);           /* Open all files */
 
   fnbr = (fdim + 1) * (1 << fdim);                /* Compute number of vertices      */
-  fmax = (1 << (fdim * 2 - 1)) - 1;               /* Compute maximum terminal number */
   fmsk = (1 << fdim) - 1;                         /* Get maximum position number     */
-
+  for (i = fdim, fmax = 1; i > 0; i --)           /* Compute maximum terminal number */
+    fmax = (fmax << 2) | 2;
+  fmax  |= 1;
+  
   fprintf (C_filepntrarcout, "deco\n0\n" SCOTCH_NUMSTRING "\t" SCOTCH_NUMSTRING "\n", /* Print file header */
            (SCOTCH_Num) fnbr,                     /* Print number of terminal domains */
            (SCOTCH_Num) fmax);                    /* Print the biggest terminal value */
@@ -183,15 +185,16 @@ char *                      argv[])
         t |= v.pos & ((1 << (v.lvl - 1)) - 1);    /* Bipartition the chain following the lowest bits */
       }
 
-      printf (((v.lvl == fdim) && (v.pos == fmsk)) /* Print terminal domain number */
-               ? SCOTCH_NUMSTRING "\n\n" : SCOTCH_NUMSTRING " ", t);
+      fprintf (C_filepntrarcout, SCOTCH_NUMSTRING "\t1\t" SCOTCH_NUMSTRING "\n",
+               (SCOTCH_Num) C_vertLabl (&v),      /* Print terminal label  */
+               (SCOTCH_Num) t);                   /* Print terminal number */
     }
   }
 
   if ((C_queueInit (&C_distaQueue, fnbr) != 0) || /* Allocate distance array */
       ((C_distaTab = (C_VertDist *) memAlloc (fnbr * sizeof (C_VertDist))) == NULL)) {
     errorPrint ("main: out of memory");
-    return     (1);
+    return     (EXIT_FAILURE);
   }
 
   for (v.lvl = 0; v.lvl <= fdim; v.lvl ++) {      /* For all vertices */
@@ -244,5 +247,5 @@ char *                      argv[])
 
   fileBlockClose (C_fileTab, C_FILENBR);          /* Always close explicitely to end eventual (un)compression tasks */
 
-  return (0);
+  return (EXIT_SUCCESS);
 }
